diff --git a/app/test/test_bitmap.c b/app/test/test_bitmap.c
index e9c61590aef7..8cb5d0954a2b 100644
--- a/app/test/test_bitmap.c
+++ b/app/test/test_bitmap.c
@@ -33,7 +33,7 @@ test_bitmap_scan_operations(struct rte_bitmap *bmp)
 	}
 
 	if (slab1_magic != out_slab) {
-		printf("Scan operation sanity failed.\n");
+		printf("Scan operation magic number check failed.\n");
 		return TEST_FAILED;
 	}
 
@@ -43,7 +43,7 @@ test_bitmap_scan_operations(struct rte_bitmap *bmp)
 	}
 
 	if (slab2_magic != out_slab) {
-		printf("Scan operation sanity failed.\n");
+		printf("Scan operation magic number check failed.\n");
 		return TEST_FAILED;
 	}
 
diff --git a/app/test/test_bpf.c b/app/test/test_bpf.c
index f5af5e8a3f4a..347b672ac211 100644
--- a/app/test/test_bpf.c
+++ b/app/test/test_bpf.c
@@ -3329,9 +3329,9 @@ test_bpf_match(pcap_t *pcap, const char *str,
 	return ret;
 }
 
-/* Basic sanity test can we match a IP packet */
+/* Basic test can we match a IP packet */
 static int
-test_bpf_filter_sanity(pcap_t *pcap)
+test_bpf_filter_match(pcap_t *pcap)
 {
 	const uint32_t plen = 100;
 	struct rte_mbuf mb, *m;
@@ -3463,7 +3463,7 @@ test_bpf_convert(void)
 		return -1;
 	}
 
-	rc = test_bpf_filter_sanity(pcap);
+	rc = test_bpf_filter_match(pcap);
 	for (i = 0; i < RTE_DIM(sample_filters); i++)
 		rc |= test_bpf_filter(pcap, sample_filters[i]);
 
diff --git a/app/test/test_common.c b/app/test/test_common.c
index f89e1eb7ee0d..c7ce8ea32a77 100644
--- a/app/test/test_common.c
+++ b/app/test/test_common.c
@@ -18,7 +18,7 @@
 	{printf(x "() test failed!\n");\
 	return -1;}
 
-/* this is really a sanity check */
+/* this is really a consistency check */
 static int
 test_macros(int __rte_unused unused_parm)
 {
diff --git a/app/test/test_dmadev.c b/app/test/test_dmadev.c
index 0736ff2a1867..b54319f763f4 100644
--- a/app/test/test_dmadev.c
+++ b/app/test/test_dmadev.c
@@ -927,7 +927,7 @@ test_dma(void)
 {
 	int i;
 
-	/* basic sanity on dmadev infrastructure */
+	/* basic validation on dmadev infrastructure */
 	if (test_apis() < 0)
 		ERR_RETURN("Error performing API tests\n");
 
diff --git a/app/test/test_eal_flags.c b/app/test/test_eal_flags.c
index d2b91e20750e..edbe1be50096 100644
--- a/app/test/test_eal_flags.c
+++ b/app/test/test_eal_flags.c
@@ -314,7 +314,7 @@ get_number_of_sockets(void)
 
 /*
  * Test that the app doesn't run with invalid allow option.
- * Final tests ensures it does run with valid options as sanity check (one
+ * Final tests ensures it does run with valid options as basic test (one
  * test for with Domain+BDF, second for just with BDF)
  */
 static int
@@ -382,7 +382,7 @@ test_allow_flag(void)
 
 /*
  * Test that the app doesn't run with invalid blocklist option.
- * Final test ensures it does run with valid options as sanity check
+ * Final test ensures it does run with valid options as basic check.
  */
 static int
 test_invalid_b_flag(void)
@@ -429,7 +429,7 @@ test_invalid_b_flag(void)
 
 /*
  *  Test that the app doesn't run with invalid vdev option.
- *  Final test ensures it does run with valid options as sanity check
+ *  Final test ensures it does run with valid options basic check.
  */
 static int
 test_invalid_vdev_flag(void)
@@ -554,7 +554,7 @@ test_missing_c_flag(void)
 	/* bad coremask value */
 	const char *argv3[] = { prgname, prefix, mp_flag,
 				"-c", "error" };
-	/* sanity check of tests - valid coremask value */
+	/* check of tests - valid coremask value */
 	const char *argv4[] = { prgname, prefix, mp_flag,
 				"-c", "1" };
 	/* -l flag but no corelist value */
@@ -581,7 +581,7 @@ test_missing_c_flag(void)
 				"-l", RTE_STR(RTE_MAX_LCORE) };
 	const char * const argv14[] = { prgname, prefix, mp_flag,
 				"-l", "1-"RTE_STR(RTE_MAX_LCORE) };
-	/* sanity check test - valid corelist value */
+	/* check test - valid corelist value */
 	const char * const argv15[] = { prgname, prefix, mp_flag,
 				 "-l", "1-2,3" };
 
@@ -613,7 +613,7 @@ test_missing_c_flag(void)
 				 "--lcores", "(4-7)=(1,3)" };
 	const char * const argv28[] = { prgname, prefix, mp_flag,
 				 "--lcores", "[4-7]@(1,3)" };
-	/* sanity check of tests - valid lcores value */
+	/* more complex valid lcores value */
 	const char * const argv29[] = { prgname, prefix, mp_flag,
 				 "--lcores",
 				 "0-1,2@(5-7),(3-5)@(0,2),(0,6),7"};
@@ -744,7 +744,7 @@ test_main_lcore_flag(void)
 
 /*
  * Test that the app doesn't run with invalid -n flag option.
- * Final test ensures it does run with valid options as sanity check
+ * Final test ensures it does run with valid options as basic check.
  * Since -n is not compulsory for MP, we instead use --no-huge and --no-shconf
  * flags.
  */
@@ -772,10 +772,10 @@ test_invalid_n_flag(void)
 	/* zero is invalid */
 	const char *argv3[] = { prgname, prefix, no_huge, no_shconf,
 				"-n", "0" };
-	/* sanity test - check with good value */
+	/* check with good value */
 	const char *argv4[] = { prgname, prefix, no_huge, no_shconf,
 				"-n", "2" };
-	/* sanity test - check with no -n flag */
+	/* check with no -n flag */
 	const char *argv5[] = { prgname, prefix, no_huge, no_shconf};
 
 	if (launch_proc(argv1) == 0
@@ -977,7 +977,7 @@ test_misc_flags(void)
 	 * All cases, apart from the first, app should run.
 	 * No further testing of output done.
 	 */
-	/* sanity check - failure with invalid option */
+	/* failure with invalid option */
 	const char *argv0[] = {prgname, prefix, mp_flag, "--invalid-opt"};
 
 	/* With --no-pci */
diff --git a/app/test/test_hash.c b/app/test/test_hash.c
index 3e45afaa67fc..f521ce7f679a 100644
--- a/app/test/test_hash.c
+++ b/app/test/test_hash.c
@@ -1088,7 +1088,7 @@ fbk_hash_unit_test(void)
 		.socket_id = 0,
 	};
 
-	/* this is a sanity check for "same name" test
+	/* this is a check for "same name" test
 	 * creating this hash will check if we are actually able to create
 	 * multiple hashes with different names (instead of having just one).
 	 */
diff --git a/app/test/test_interrupts.c b/app/test/test_interrupts.c
index b59ab426999c..88105b78a455 100644
--- a/app/test/test_interrupts.c
+++ b/app/test/test_interrupts.c
@@ -48,7 +48,7 @@ static union intr_pipefds pfds;
  * Check if the interrupt handle is valid.
  */
 static inline int
-test_interrupt_handle_sanity_check(struct rte_intr_handle *intr_handle)
+test_interrupt_handle_check(struct rte_intr_handle *intr_handle)
 {
 	if (!intr_handle || rte_intr_fd_get(intr_handle) < 0)
 		return -1;
@@ -164,7 +164,7 @@ test_interrupt_handle_compare(struct rte_intr_handle *intr_handle_l,
 #else
 /* to be implemented for bsd later */
 static inline int
-test_interrupt_handle_sanity_check(struct rte_intr_handle *intr_handle)
+test_interrupt_handle_check(struct rte_intr_handle *intr_handle)
 {
 	RTE_SET_USED(intr_handle);
 
@@ -215,7 +215,7 @@ test_interrupt_callback(void *arg)
 		return;
 	}
 
-	if (test_interrupt_handle_sanity_check(intr_handle) < 0) {
+	if (test_interrupt_handle_check(intr_handle) < 0) {
 		printf("null or invalid intr_handle for %s\n", __func__);
 		flag = -1;
 		return;
@@ -241,7 +241,8 @@ static void
 test_interrupt_callback_1(void *arg)
 {
 	struct rte_intr_handle *intr_handle = arg;
-	if (test_interrupt_handle_sanity_check(intr_handle) < 0) {
+
+	if (test_interrupt_handle_check(intr_handle) < 0) {
 		printf("null or invalid intr_handle for %s\n", __func__);
 		flag = -1;
 		return;
diff --git a/app/test/test_link_bonding_mode4.c b/app/test/test_link_bonding_mode4.c
index 21c512c94b89..95dd52848fb9 100644
--- a/app/test/test_link_bonding_mode4.c
+++ b/app/test/test_link_bonding_mode4.c
@@ -224,7 +224,7 @@ add_slave(struct slave_conf *slave, uint8_t start)
 	struct rte_ether_addr addr, addr_check;
 	int retval;
 
-	/* Some sanity check */
+	/* Some basic tests. */
 	RTE_VERIFY(test_params.slave_ports <= slave &&
 		slave - test_params.slave_ports < (int)RTE_DIM(test_params.slave_ports));
 	RTE_VERIFY(slave->bonded == 0);
diff --git a/app/test/test_mbuf.c b/app/test/test_mbuf.c
index db9bb3caeea2..3add3d8717de 100644
--- a/app/test/test_mbuf.c
+++ b/app/test/test_mbuf.c
@@ -1723,7 +1723,7 @@ test_mbuf_validate_tx_offload(const char *test_name,
 	struct rte_mbuf *m = NULL;
 	int ret = 0;
 
-	/* alloc a mbuf and do sanity check */
+	/* alloc a mbuf and do some basic checks */
 	m = rte_pktmbuf_alloc(pktmbuf_pool);
 	if (m == NULL)
 		GOTO_FAIL("%s: mbuf allocation failed!\n", __func__);
diff --git a/app/test/test_rawdev.c b/app/test/test_rawdev.c
index 3c780e3f9e96..c807bf90d9c3 100644
--- a/app/test/test_rawdev.c
+++ b/app/test/test_rawdev.c
@@ -47,7 +47,7 @@ test_rawdev_selftests(void)
 	int ret = 0;
 	int i;
 
-	/* basic sanity on rawdev infrastructure */
+	/* basic check on rawdev infrastructure */
 	if (test_rawdev_selftest_skeleton() < 0)
 		return -1;
 
diff --git a/app/test/test_timer.c b/app/test/test_timer.c
index 0c36dc9010b0..6615ce536443 100644
--- a/app/test/test_timer.c
+++ b/app/test/test_timer.c
@@ -491,11 +491,11 @@ timer_basic_main_loop(__rte_unused void *arg)
 }
 
 static int
-timer_sanity_check(void)
+timer_check(void)
 {
 #ifdef RTE_LIBEAL_USE_HPET
 	if (eal_timer_source != EAL_TIMER_HPET) {
-		printf("Not using HPET, can't sanity check timer sources\n");
+		printf("Not using HPET, can't check timer sources\n");
 		return 0;
 	}
 
@@ -539,9 +539,9 @@ test_timer(void)
 		return TEST_SKIPPED;
 	}
 
-	/* sanity check our timer sources and timer config values */
-	if (timer_sanity_check() < 0) {
-		printf("Timer sanity checks failed\n");
+	/* check our timer sources and timer config values */
+	if (timer_check() < 0) {
+		printf("Timer checks failed\n");
 		return TEST_FAILED;
 	}
 

diff --git a/app/test/test_distributor.c b/app/test/test_distributor.c
index 3efa4af10439..36e246927aac 100644
--- a/app/test/test_distributor.c
+++ b/app/test/test_distributor.c
@@ -80,7 +80,7 @@ clear_packet_count(void)
 			__ATOMIC_RELAXED);
 }
 
-/* this is the basic worker function for sanity test
+/* this is the basic worker function
  * it does nothing but return packets and count them.
  */
 static int
@@ -105,7 +105,7 @@ handle_work(void *arg)
 	return 0;
 }
 
-/* do basic sanity testing of the distributor. This test tests the following:
+/* do basic testing of the distributor. This test tests the following:
  * - send 32 packets through distributor with the same tag and ensure they
  *   all go to the one worker
  * - send 32 packets through the distributor with two different tags and
@@ -117,7 +117,7 @@ handle_work(void *arg)
  *   not necessarily in the same order (as different flows).
  */
 static int
-sanity_test(struct worker_params *wp, struct rte_mempool *p)
+basic_test(struct worker_params *wp, struct rte_mempool *p)
 {
 	struct rte_distributor *db = wp->dist;
 	struct rte_mbuf *bufs[BURST];
@@ -126,7 +126,7 @@ sanity_test(struct worker_params *wp, struct rte_mempool *p)
 	unsigned int retries;
 	unsigned int processed;
 
-	printf("=== Basic distributor sanity tests ===\n");
+	printf("=== Basic distributor tests ===\n");
 	clear_packet_count();
 	if (rte_mempool_get_bulk(p, (void *)bufs, BURST) != 0) {
 		printf("line %d: Error getting mbufs from pool\n", __LINE__);
@@ -163,7 +163,7 @@ sanity_test(struct worker_params *wp, struct rte_mempool *p)
 		printf("Worker %u handled %u packets\n", i,
 			__atomic_load_n(&worker_stats[i].handled_packets,
 					__ATOMIC_RELAXED));
-	printf("Sanity test with all zero hashes done.\n");
+	printf("Test with all zero hashes done.\n");
 
 	/* pick two flows and check they go correctly */
 	if (rte_lcore_count() >= 3) {
@@ -191,7 +191,7 @@ sanity_test(struct worker_params *wp, struct rte_mempool *p)
 				__atomic_load_n(
 					&worker_stats[i].handled_packets,
 					__ATOMIC_RELAXED));
-		printf("Sanity test with two hash values done\n");
+		printf("Test with two hash values done\n");
 	}
 
 	/* give a different hash value to each packet,
@@ -219,11 +219,11 @@ sanity_test(struct worker_params *wp, struct rte_mempool *p)
 		printf("Worker %u handled %u packets\n", i,
 			__atomic_load_n(&worker_stats[i].handled_packets,
 					__ATOMIC_RELAXED));
-	printf("Sanity test with non-zero hashes done\n");
+	printf("Test with non-zero hashes done\n");
 
 	rte_mempool_put_bulk(p, (void *)bufs, BURST);
 
-	/* sanity test with BIG_BATCH packets to ensure they all arrived back
+	/* test with BIG_BATCH packets to ensure they all arrived back
 	 * from the returned packets function */
 	clear_packet_count();
 	struct rte_mbuf *many_bufs[BIG_BATCH], *return_bufs[BIG_BATCH];
@@ -288,7 +288,7 @@ sanity_test(struct worker_params *wp, struct rte_mempool *p)
 			return -1;
 		}
 	}
-	printf("Sanity test of returned packets done\n");
+	printf("Test of returned packets done\n");
 
 	rte_mempool_put_bulk(p, (void *)many_bufs, BIG_BATCH);
 
@@ -326,20 +326,20 @@ handle_work_with_free_mbufs(void *arg)
 	return 0;
 }
 
-/* Perform a sanity test of the distributor with a large number of packets,
+/* Perform a test of the distributor with a large number of packets,
  * where we allocate a new set of mbufs for each burst. The workers then
  * free the mbufs. This ensures that we don't have any packet leaks in the
  * library.
  */
 static int
-sanity_test_with_mbuf_alloc(struct worker_params *wp, struct rte_mempool *p)
+basic_test_with_mbuf_alloc(struct worker_params *wp, struct rte_mempool *p)
 {
 	struct rte_distributor *d = wp->dist;
 	unsigned i;
 	struct rte_mbuf *bufs[BURST];
 	unsigned int processed;
 
-	printf("=== Sanity test with mbuf alloc/free (%s) ===\n", wp->name);
+	printf("=== Test with mbuf alloc/free (%s) ===\n", wp->name);
 
 	clear_packet_count();
 	for (i = 0; i < ((1<<ITER_POWER)); i += BURST) {
@@ -367,7 +367,7 @@ sanity_test_with_mbuf_alloc(struct worker_params *wp, struct rte_mempool *p)
 		return -1;
 	}
 
-	printf("Sanity test with mbuf alloc/free passed\n\n");
+	printf("Test with mbuf alloc/free passed\n\n");
 	return 0;
 }
 
@@ -433,13 +433,13 @@ handle_work_for_shutdown_test(void *arg)
 }
 
 
-/* Perform a sanity test of the distributor with a large number of packets,
+/* Perform a test of the distributor with a large number of packets,
  * where we allocate a new set of mbufs for each burst. The workers then
  * free the mbufs. This ensures that we don't have any packet leaks in the
  * library.
  */
 static int
-sanity_test_with_worker_shutdown(struct worker_params *wp,
+basic_test_with_worker_shutdown(struct worker_params *wp,
 		struct rte_mempool *p)
 {
 	struct rte_distributor *d = wp->dist;
@@ -449,7 +449,7 @@ sanity_test_with_worker_shutdown(struct worker_params *wp,
 	unsigned int failed = 0;
 	unsigned int processed = 0;
 
-	printf("=== Sanity test of worker shutdown ===\n");
+	printf("=== Test of worker shutdown ===\n");
 
 	clear_packet_count();
 
@@ -515,7 +515,7 @@ sanity_test_with_worker_shutdown(struct worker_params *wp,
 	if (failed)
 		return -1;
 
-	printf("Sanity test with worker shutdown passed\n\n");
+	printf("Test with worker shutdown passed\n\n");
 	return 0;
 }
 
@@ -611,13 +611,13 @@ handle_and_mark_work(void *arg)
 	return 0;
 }
 
 /* sanity_mark_test sends packets to workers which mark them.
  * Every packet has also encoded sequence number.
  * The returned packets are sorted and verified if they were handled
  * by proper workers.
  */
 static int
-sanity_mark_test(struct worker_params *wp, struct rte_mempool *p)
+mark_test(struct worker_params *wp, struct rte_mempool *p)
 {
 	const unsigned int buf_count = 24;
 	const unsigned int burst = 8;
@@ -898,13 +898,13 @@ test_distributor(void)
 
 		rte_eal_mp_remote_launch(handle_work,
 				&worker_params, SKIP_MAIN);
-		if (sanity_test(&worker_params, p) < 0)
+		if (basic_test(&worker_params, p) < 0)
 			goto err;
 		quit_workers(&worker_params, p);
 
 		rte_eal_mp_remote_launch(handle_work_with_free_mbufs,
 				&worker_params, SKIP_MAIN);
-		if (sanity_test_with_mbuf_alloc(&worker_params, p) < 0)
+		if (basic_test_with_mbuf_alloc(&worker_params, p) < 0)
 			goto err;
 		quit_workers(&worker_params, p);
 
@@ -912,7 +912,7 @@ test_distributor(void)
 			rte_eal_mp_remote_launch(handle_work_for_shutdown_test,
 					&worker_params,
 					SKIP_MAIN);
-			if (sanity_test_with_worker_shutdown(&worker_params,
+			if (basic_test_with_worker_shutdown(&worker_params,
 					p) < 0)
 				goto err;
 			quit_workers(&worker_params, p);
@@ -927,7 +927,7 @@ test_distributor(void)
 
 			rte_eal_mp_remote_launch(handle_and_mark_work,
 					&worker_params, SKIP_MAIN);
-			if (sanity_mark_test(&worker_params, p) < 0)
+			if (mark_test(&worker_params, p) < 0)
 				goto err;
 			quit_workers(&worker_params, p);
 
@@ -611,13 +611,13 @@ handle_and_mark_work(void *arg)
 }
 
-/* sanity_mark_test sends packets to workers which mark them.
+/* mark_test sends packets to workers which mark them.
  * Every packet has also encoded sequence number.
  * The returned packets are sorted and verified if they were handled